==> gtk+3-3.0.10-i486-1gsb.txz: install/doinst.sh <==
( cd usr/doc/gtk+-3.0.10 ; rm -rf gail-libgail-util )
( cd usr/doc/gtk+-3.0.10 ; ln -sf /usr/share/gtk-doc/html/gail-libgail-util gail-libgail-util )
( cd usr/doc/gtk+-3.0.10 ; rm -rf gtk )
( cd usr/doc/gtk+-3.0.10 ; ln -sf /usr/share/gtk-doc/html/gtk gtk )
( cd usr/doc/gtk+-3.0.10 ; rm -rf gdk )
( cd usr/doc/gtk+-3.0.10 ; ln -sf /usr/share/gtk-doc/html/gdk gdk )
( cd usr/bin ; rm -rf gtk-query-immodules-3.0 )
( cd usr/bin ; ln -sf gtk-query-immodules-3.0-32 gtk-query-immodules-3.0 )
( cd usr/lib ; rm -rf libgtk-3.so.0 )
( cd usr/lib ; ln -sf libgtk-3.so.0.0.10 libgtk-3.so.0 )
( cd usr/lib ; rm -rf libgdk-3.so )
( cd usr/lib ; ln -sf libgdk-3.so.0.0.10 libgdk-3.so )
( cd usr/lib ; rm -rf libgailutil-3.so )
( cd usr/lib ; ln -sf libgailutil-3.so.0.0.0 libgailutil-3.so )
( cd usr/lib ; rm -rf libgtk-3.so )
( cd usr/lib ; ln -sf libgtk-3.so.0.0.10 libgtk-3.so )
( cd usr/lib ; rm -rf libgdk-3.so.0 )
( cd usr/lib ; ln -sf libgdk-3.so.0.0.10 libgdk-3.so.0 )
( cd usr/lib ; rm -rf libgailutil-3.so.0 )
( cd usr/lib ; ln -sf libgailutil-3.so.0.0.0 libgailutil-3.so.0 )

#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
if [ -d etc/gtk-3.0/$(uname -m)-slackware-linux ]; then
  config etc/gtk-3.0/$(uname -m)-slackware-linux/im-multipress.conf.new
  config etc/gtk-3.0/$(uname -m)-slackware-linux/gtkrc.new
elif [ -d etc/gtk-3.0/i486-slackware-linux ]; then
  config etc/gtk-3.0/i486-slackware-linux/im-multipress.conf.new
  config etc/gtk-3.0/i486-slackware-linux/gtkrc.new
elif [ -d etc/gtk-3.0/*-slackware-linux ]; then
  config etc/gtk-3.0/*-slackware-linux/im-multipress.conf.new
  config etc/gtk-3.0/*-slackware-linux/gtkrc.new
fi

# Since the use of icon caching is optional, and has to be kept in sync
# somehow (like a "registry" through a cron job, or whatever, I tend to
# think the user should be the one to choose if they really want to set
# this up or not:
#
# Example:
#for dir in /usr/share/icons/* ; do
#  if [ -d $dir ]; then
#    /usr/bin/gtk-update-icon-cache -f -t $dir 1> /dev/null 2> /dev/null
#  fi
#done
mkdir -p etc/gtk-3.0
# chroot . rm -f /usr/share/icons/*/icon-theme.cache 1> /dev/null 2> /dev/null

# Run this if we are on an installed system.  Otherwise it will be
# handled on first boot.
if [ -x /usr/bin/update-gtk-immodules-3.0 ]; then
  /usr/bin/update-gtk-immodules-3.0
fi

# glib2 compile schemas
if [ -x usr/bin/glib-compile-schemas ]; then
  usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas
fi

==> gtk+3-3.2.3-i486-1gsb.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf gtk-query-immodules-3.0 )
( cd usr/bin ; ln -sf gtk-query-immodules-3.0-32 gtk-query-immodules-3.0 )
( cd usr/lib ; rm -rf libgdk-3.so.0 )
( cd usr/lib ; ln -sf libgdk-3.so.0.200.3 libgdk-3.so.0 )
( cd usr/lib ; rm -rf libgtk-3.so.0 )
( cd usr/lib ; ln -sf libgtk-3.so.0.200.3 libgtk-3.so.0 )
( cd usr/lib ; rm -rf libgailutil-3.so.0 )
( cd usr/lib ; ln -sf libgailutil-3.so.0.0.0 libgailutil-3.so.0 )
( cd usr/lib ; rm -rf libgailutil-3.so )
( cd usr/lib ; ln -sf libgailutil-3.so.0.0.0 libgailutil-3.so )
( cd usr/lib ; rm -rf libgdk-3.so )
( cd usr/lib ; ln -sf libgdk-3.so.0.200.3 libgdk-3.so )
( cd usr/lib ; rm -rf libgtk-3.so )
( cd usr/lib ; ln -sf libgtk-3.so.0.200.3 libgtk-3.so )
( cd usr/doc/gtk+-3.2.3 ; rm -rf gail-libgail-util )
( cd usr/doc/gtk+-3.2.3 ; ln -sf /usr/share/gtk-doc/html/gail-libgail-util gail-libgail-util )
( cd usr/doc/gtk+-3.2.3 ; rm -rf gtk )
( cd usr/doc/gtk+-3.2.3 ; ln -sf /usr/share/gtk-doc/html/gtk gtk )
( cd usr/doc/gtk+-3.2.3 ; rm -rf gdk )
( cd usr/doc/gtk+-3.2.3 ; ln -sf /usr/share/gtk-doc/html/gdk gdk )

#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
if [ -d etc/gtk-3.0/$(uname -m)-slackware-linux ]; then
  #config etc/gtk-3.0/$(uname -m)-slackware-linux/im-multipress.conf.new
  config etc/gtk-3.0/$(uname -m)-slackware-linux/gtkrc.new
elif [ -d etc/gtk-3.0/i486-slackware-linux ]; then
  #config etc/gtk-3.0/i486-slackware-linux/im-multipress.conf.new
  config etc/gtk-3.0/i486-slackware-linux/gtkrc.new
elif [ -d etc/gtk-3.0/*-slackware-linux ]; then
  #config etc/gtk-3.0/*-slackware-linux/im-multipress.conf.new
  config etc/gtk-3.0/*-slackware-linux/gtkrc.new
fi

# Since the use of icon caching is optional, and has to be kept in sync
# somehow (like a "registry" through a cron job, or whatever, I tend to
# think the user should be the one to choose if they really want to set
# this up or not:
#
# Example:
#for dir in /usr/share/icons/* ; do
#  if [ -d $dir ]; then
#    /usr/bin/gtk-update-icon-cache -f -t $dir 1> /dev/null 2> /dev/null
#  fi
#done
mkdir -p etc/gtk-3.0
# chroot . rm -f /usr/share/icons/*/icon-theme.cache 1> /dev/null 2> /dev/null

# Run this if we are on an installed system.  Otherwise it will be
# handled on first boot.
if [ -x /usr/bin/update-gtk-immodules-3.0 ]; then
  /usr/bin/update-gtk-immodules-3.0
fi

# glib2 compile schemas
if [ -x usr/bin/glib-compile-schemas ]; then
  usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas
fi
